@@ -1,7 +1,7 @@
 package Calendar::Dates::ID::Holiday;
 
 our $DATE = '2019-02-14'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,7 +10,7 @@ use warnings;
 use Calendar::Indonesia::Holiday;
 use Role::Tiny::With;
 
-with 'Calendar::DatesRoles::FromData';
+with 'Calendar::DatesRoles::FromEntriesVar';
 
 our @ENTRIES;
 my $res = Calendar::Indonesia::Holiday::list_id_holidays(detail=>1);
@@ -45,7 +45,7 @@ Calendar::Dates::ID::Holiday - Indonesian holiday calendar
 
 =head1 VERSION
 
-This document describes version 0.005 of Calendar::Dates::ID::Holiday (from Perl distribution Calendar-Dates-ID-Holiday), released on 2019-02-14.
+This document describes version 0.006 of Calendar::Dates::ID::Holiday (from Perl distribution Calendar-Dates-ID-Holiday), released on 2019-02-14.
 
 =head1 SYNOPSIS
 
